package net.wanji.utc.cache;

import net.wanji.databus.dao.mapper.CrossInfoMapper;
import net.wanji.databus.dao.mapper.ManufacturerInfoMapper;
import net.wanji.databus.po.CrossInfoPO;
import net.wanji.databus.po.ManufacturerInfoPO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * @author duanruiming
 * @date 2023/05/23 9:44
 */
@Component
public class CrossInfoCache implements CommandLineRunner {

    @Resource
    private CrossInfoMapper crossInfoMapper;
    @Resource
    private ManufacturerInfoMapper manufacturerInfoMapper;

    private static List<CrossInfoPO> crossInfoList = new ArrayList<>();

    /**
     * 通过路口编号获取厂商编码
     *
     * @param crossId
     * @return
     */
    public String getManufacturerCodeByCrossId(String crossId) throws Exception {
        CrossInfoPO crossInfoPO = getCrossInfoPO(crossId);
        if (Objects.nonNull(crossInfoPO)) {
            Integer manufacturerId = crossInfoPO.getManufacturerId();
            ManufacturerInfoPO manufacturerInfoPO = manufacturerInfoMapper.selectById(manufacturerId);
            return manufacturerInfoPO.getCode();
        }
        return null;
    }


    /**
     * 通过路口编号获取路口信息
     *
     * @param crossId
     * @return
     */
    public CrossInfoPO getCrossInfoPO(String crossId) {
        if (!CollectionUtils.isEmpty(crossInfoList)) {
            for (CrossInfoPO crossInfoPO : crossInfoList) {
                if (StringUtils.equals(crossId, crossInfoPO.getId())) {
                    return crossInfoPO;
                }
            }
        }
        return null;
    }

    @Override
    public void run(String... args) throws Exception {
        init();
    }

    public void init() {
        List<CrossInfoPO> crossInfoPOList = crossInfoMapper.selectAll();
        if (!CollectionUtils.isEmpty(crossInfoPOList)) {
            crossInfoList = crossInfoPOList;
        }
    }
}
